Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Controller ¶
type Controller struct {
// contains filtered or unexported fields
}
Controller assigns sandboxes to nodes for execution. It watches sandbox entities and adds a ScheduleKey attribute to assign each sandbox to an available node.
Stateful sandboxes (those with miren disk volumes) are scheduled to the coordinator node, while stateless sandboxes prefer runner nodes when available.
Implements controller.ReconcileControllerI[*compute_v1alpha.Sandbox]
func NewController ¶
func NewController( log *slog.Logger, eac *entityserver_v1alpha.EntityAccessClient, ) *Controller
NewController creates a new scheduler controller
func (*Controller) Init ¶
func (c *Controller) Init(ctx context.Context) error
Init initializes the controller. Required by ReconcileControllerI.
func (*Controller) Reconcile ¶
func (c *Controller) Reconcile(ctx context.Context, sandbox *compute_v1alpha.Sandbox, meta *entity.Meta) error
Reconcile ensures the sandbox is assigned to a node. Called by the controller framework for both Add and Update events.
Click to show internal directories.
Click to hide internal directories.